StaticSuggestionProvider class
A simple suggestion provider that returns static suggestions.
- Inheritance
-
- Object
- SuggestionProvider
- StaticSuggestionProvider
Constructors
-
StaticSuggestionProvider(List<
Suggestion> _suggestions, {String? fieldType, String? platform})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxSuggestions → int
-
Returns the maximum number of suggestions this provider should return.
no setterinherited
- priority → int
-
Returns the priority of this provider (higher numbers = higher priority).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsWasm → bool
-
Returns whether this provider supports WASM mode.
no setterinherited
Methods
-
canHandle(
SuggestionContext context) → bool -
Returns whether this provider can handle the given context.
override
-
getSuggestions(
SuggestionContext context) → Future< List< Suggestion> > -
Returns a list of suggestions based on the given context.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsPlatform(
String platform) → bool -
Returns whether this provider should be used for the given platform.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited